@@ -15,28 +15,23 @@
 #
 
 
-
 import os
 import os.path as op
-from builtins import object
 
 from .rest_conf import RestmapConf, WebConf
 
-__all__ = [
-    'RestBuilderError',
-    'RestBuilder'
-]
+__all__ = ["RestBuilderError", "RestBuilder"]
 
 
 class RestBuilderError(Exception):
     pass
 
 
-class _RestBuilderOutput(object):
+class _RestBuilderOutput:
 
-    readme = 'README'
-    default = 'default'
-    bin = 'bin'
+    readme = "README"
+    default = "default"
+    bin = "bin"
 
     def __init__(self, path, product):
         self._path = path
@@ -57,21 +52,13 @@ class _RestBuilderOutput(object):
 
     def save(self):
         for full_name, contents in list(self._content.items()):
-            full_content = '\n\n'.join(contents)
-            with open(full_name, 'w') as f:
+            full_content = "\n\n".join(contents)
+            with open(full_name, "w") as f:
                 f.writelines(full_content)
 
 
-class RestBuilder(object):
-
-    def __init__(
-            self,
-            schema,
-            handler,
-            output_path,
-            *args,
-            **kwargs
-    ):
+class RestBuilder:
+    def __init__(self, schema, handler, output_path, *args, **kwargs):
         """
 
         :param schema:
@@ -103,40 +90,38 @@ class RestBuilder(object):
         for endpoint in self._schema.endpoints:
             # If the endpoint is oauth, which is for getting accesstoken. Conf file entries should not get created.
             if endpoint._name != "oauth":
-                if endpoint._name == 'settings':
+                if endpoint._name == "settings":
                     self.output.put(
                         self.output.default,
-                        endpoint.conf_name + '.conf',
+                        endpoint.conf_name + ".conf",
                         endpoint.generate_default_conf(),
                     )
 
                 self.output.put(
                     self.output.readme,
-                    endpoint.conf_name + '.conf.spec',
+                    endpoint.conf_name + ".conf.spec",
                     endpoint.generate_spec(),
                 )
 
                 # Add data input of self defined conf to inputs.conf.spec
                 if endpoint._entities[0] and endpoint._entities[0]._conf_name:
                     lines = [
-                        '[' + endpoint._name + '://<name>]',
-                        'placeholder = placeholder'
+                        "[" + endpoint._name + "://<name>]",
+                        "placeholder = placeholder",
                     ]
                     self.output.put(
-                        self.output.readme,
-                        'inputs.conf.spec',
-                        '\n'.join(lines)
+                        self.output.readme, "inputs.conf.spec", "\n".join(lines)
                     )
 
             self.output.put(
                 self.output.bin,
-                endpoint.rh_name + '.py',
+                endpoint.rh_name + ".py",
                 endpoint.generate_rh(self._handler),
             )
 
         self.output.put(
             self.output.default,
-            'restmap.conf',
+            "restmap.conf",
             RestmapConf.build(
                 self._schema.endpoints,
                 self._schema.namespace,
@@ -145,7 +130,7 @@ class RestBuilder(object):
         )
         self.output.put(
             self.output.default,
-            'web.conf',
+            "web.conf",
             WebConf.build(self._schema.endpoints),
         )
         self.output.save()
